# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 CERN.
#
# Invenio-Communities is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Facets for the members search."""

from flask_babelex import gettext as _
from invenio_records_resources.services.records.facets import TermsFacet

from ...proxies import current_roles

role = TermsFacet(
    field="role",
    label=_("Role"),
    value_labels=lambda keys: {k: current_roles[k].title for k in keys},
)

status = TermsFacet(
    field="request.status",
    label=_("Status"),
    value_labels={
        "submitted": _("Submitted"),
        "expired": _("Expired"),
        "accepted": _("Accepted"),
        "declined": _("Declined"),
        "cancelled": _("Cancelled"),
    },
)

visibility = TermsFacet(
    field="visible",
    label=_("Visibility"),
    value_labels={"true": _("Public"), "false": _("Hidden")},
)

is_open = TermsFacet(
    field="request.is_open",
    label=_("Status"),
    value_labels={"true": _("Open"), "false": _("Closed")},
)



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 Graz University of Technology.
#
# Invenio-Communities is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Test components."""

from copy import deepcopy
from datetime import datetime

import pytest
from invenio_access.permissions import system_identity
from invenio_oaiserver.models import OAISet

from invenio_communities.communities.services.components import OAISetComponent


def _retrieve_oaiset(service, community):
    comp = OAISetComponent(service)
    return OAISet.query.filter(
        OAISet.spec == comp._create_set_spec(community.get("slug"))
    ).first()


@pytest.fixture()
def comm(community_service, minimal_community, location):
    """Create minimal public community."""
    c = deepcopy(minimal_community)
    c["slug"] = "public-{slug}".format(
        slug=str(datetime.utcnow().timestamp()).replace(".", "-")
    )
    return community_service.create(data=c, identity=system_identity)


@pytest.fixture()
def comm_restricted(community_service, minimal_community, location):
    """Create minimal restricted community."""
    c = deepcopy(minimal_community)
    c["access"]["visibility"] = "restricted"
    c["slug"] = "restricted-{slug}".format(
        slug=str(datetime.utcnow().timestamp()).replace(".", "-")
    )
    return community_service.create(data=c, identity=system_identity)


def test_oai_set_create_community(community_service, comm, comm_restricted):
    """Set should only be created for public community."""
    oaiset = _retrieve_oaiset(service=community_service, community=comm.data)
    assert oaiset != None
    assert comm.data.get("id") in oaiset.search_pattern
    assert comm.data.get("slug") in oaiset.spec
    assert comm.data.get("metadata", {}).get("title") in oaiset.description
    assert comm.data.get("metadata", {}).get("title") in oaiset.name

    oaiset = _retrieve_oaiset(service=community_service, community=comm_restricted.data)
    assert oaiset == None


def test_oai_set_delete_community(community_service, comm, comm_restricted):
    """Set should be deleted for public community."""
    oaiset = _retrieve_oaiset(service=community_service, community=comm.data)
    assert oaiset != None

    community_service.delete(identity=system_identity, id_=comm.data.get("id"))
    oaiset = _retrieve_oaiset(service=community_service, community=comm.data)
    assert oaiset == None

    # nothing should happen for restricted communities
    community_service.delete(
        identity=system_identity, id_=comm_restricted.data.get("id")
    )


def test_oai_set_renamed(community_service, comm, comm_restricted):
    """Set should be deleted and new one created if public community is renamed."""
    new_data = deepcopy(comm.data)
    new_data["slug"] = "new-id-who-dis"
    r = community_service.rename(
        identity=system_identity, id_=comm.data.get("id"), data=new_data
    )

    # set with old id should not be there anymore
    old_oaiset = _retrieve_oaiset(service=community_service, community=comm.data)
    assert old_oaiset is None

    oaiset = _retrieve_oaiset(service=community_service, community=r.data)
    assert oaiset != None
    assert r.data.get("id") in oaiset.search_pattern
    assert r.data.get("slug") in oaiset.spec
    assert r.data.get("metadata", {}).get("title") in oaiset.description
    assert r.data.get("metadata", {}).get("title") in oaiset.name

    # nothing should happen for restricted communities
    new_data = deepcopy(comm_restricted.data)
    new_data["slug"] = "new-id-restricted-who-dis"
    r = community_service.rename(
        identity=system_identity, id_=comm_restricted.data.get("id"), data=new_data
    )
    old_oaiset = _retrieve_oaiset(service=community_service, community=r.data)
    assert old_oaiset == None


def test_oai_set_update(community_service, comm, comm_restricted):
    """Set should be updated accordingly."""
    new_data = deepcopy(comm.data)
    new_data["access"] = comm_restricted.data.get("access")
    community_service.update(identity=system_identity, id_=comm.id, data=new_data)
    # community not public anymore -> no set should be found
    oaiset = _retrieve_oaiset(service=community_service, community=comm.data)
    assert oaiset == None

    community_service.update(identity=system_identity, id_=comm.id, data=comm.data)
    # community public again -> set should be found
    oaiset = _retrieve_oaiset(service=community_service, community=comm.data)
    assert oaiset != None
    assert comm.id in oaiset.search_pattern
    assert comm.data.get("slug") in oaiset.spec
    assert comm.data.get("metadata", {}).get("title") in oaiset.description
    assert comm.data.get("metadata", {}).get("title") in oaiset.name

    new_data = deepcopy(comm.data)
    new_data["metadata"]["title"] = "new title"
    community_service.update(identity=system_identity, id_=comm.id, data=new_data)
    # community updated title -> set should update name/description
    oaiset = _retrieve_oaiset(service=community_service, community=comm.data)
    assert oaiset != None
    assert comm.id in oaiset.search_pattern
    assert comm.data.get("slug") in oaiset.spec
    assert new_data.get("metadata", {}).get("title") in oaiset.description
    assert new_data.get("metadata", {}).get("title") in oaiset.name



# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2016-2021 CERN.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Community access system field."""

from invenio_records.systemfields import SystemField


class CommunityAccess:
    """Access management per community."""

    # important: the order in tuple matters
    # TODO move to ENUM to improve code readability when using
    VISIBILITY_LEVELS = ("public", "restricted")
    MEMBER_POLICY_LEVELS = ("open", "closed")
    RECORD_POLICY_LEVELS = ("open", "closed")

    def __init__(
        self,
        visibility=None,
        member_policy=None,
        record_policy=None,
    ):
        """Create a new CommunityAccess object.

        :param visibility: The visibility level.
        """
        self.visibility = visibility or "public"
        self.member_policy = member_policy or "open"
        self.record_policy = record_policy or "open"
        self.errors = []

    def _validate_visibility_level(self, level):
        return level in self.VISIBILITY_LEVELS

    def _validate_member_policy_level(self, level):
        return level in self.MEMBER_POLICY_LEVELS

    def _validate_record_policy_level(self, level):
        return level in self.RECORD_POLICY_LEVELS

    @property
    def visibility(self):
        """Get the visibility level."""
        return self._visibility

    @visibility.setter
    def visibility(self, value):
        """Set the visibility level."""
        if not self._validate_visibility_level(value):
            raise ValueError(f"Unknown visibility level: {value}")
        self._visibility = value

    @property
    def member_policy(self):
        """Get the member policy level."""
        return self._member_policy

    @member_policy.setter
    def member_policy(self, value):
        """Set the member policy level."""
        if not self._validate_member_policy_level(value):
            raise ValueError(f"Unknown member policy level: {value}")
        self._member_policy = value

    @property
    def record_policy(self):
        """Get the record policy level."""
        return self._record_policy

    @record_policy.setter
    def record_policy(self, value):
        """Set the record policy level."""
        if not self._validate_record_policy_level(value):
            raise ValueError(f"Unknown record policy level: {value}")
        self._record_policy = value

    def dump(self):
        """Dump the field values as dictionary."""
        return {
            "visibility": self.visibility,
            "member_policy": self.member_policy,
            "record_policy": self.record_policy,
        }

    def refresh_from_dict(self, access_dict):
        """Re-initialize the Access object with the data in the access_dict."""
        new_access = self.from_dict(access_dict)
        self.visibility = new_access.visibility
        self.member_policy = new_access.member_policy
        self.record_policy = new_access.record_policy

    @classmethod
    def from_dict(
        cls,
        access_dict,
    ):
        """Create a new Access object from the specified 'access' property.

        The new ``CommunityAccess`` object will be populated with new instances
        from the configured classes.
        """
        errors = []

        access = cls(
            visibility=access_dict.get("visibility"),
            member_policy=access_dict.get("member_policy"),
            record_policy=access_dict.get("record_policy"),
        )
        access.errors = errors
        return access

    def __repr__(self):
        """Return repr(self)."""
        return (
            "<{} (visibility: {}, " "member_policy: {}, " "record_policy: {})>"
        ).format(
            type(self).__name__,
            self.visibility,
            self.member_policy,
            self.record_policy,
        )


# TODO: Move to Invenio-Records-Resources and make reusable. Duplicated from
# Invenio-RDM-Records.
class CommunityAccessField(SystemField):
    """System field for managing record access."""

    access_obj_class = CommunityAccess

    def __init__(self, key="access", access_obj_class=None):
        """Create a new RecordAccessField instance."""
        self._access_obj_class = access_obj_class or self.access_obj_class
        super().__init__(key=key)

    def _from_dict(self, instance, data):
        """Allows to override behavior in subclass."""
        return

    def obj(self, instance):
        """Get the access object."""
        obj = self._get_cache(instance)
        if obj is not None:
            return obj

        data = self.get_dictkey(instance)
        if data:
            obj = self._access_obj_class.from_dict(data)
        else:
            obj = self._access_obj_class()

        self._set_cache(instance, obj)
        return obj

    def set_obj(self, record, obj):
        """Set the access object."""
        # We accept both dicts and access class objects.
        if isinstance(obj, dict):
            obj = self._access_obj_class.from_dict(obj)

        assert isinstance(obj, self._access_obj_class)

        # We do not dump the object until the pre_commit hook
        # I.e. record.access != record['access']
        self._set_cache(record, obj)

    def __get__(self, record, owner=None):
        """Get the record's access object."""
        if record is None:
            # access by class
            return self

        # access by object
        return self.obj(record)

    def __set__(self, record, obj):
        """Set the records access object."""
        self.set_obj(record, obj)

    def pre_commit(self, record):
        """Dump the configured values before the record is committed."""
        obj = self.obj(record)
        if obj is not None:
            # only set the 'access' property if one was present in the
            # first place -- this was a problem in the unit test:
            # tests/resources/test_resources.py:test_simple_flow
            record["access"] = obj.dump()



# -*- coding: utf-8 -*-
#
# Copyright (C) 2021 CERN.
#
# Invenio-Communities is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Data layer tests for record/community integration."""

import pytest
from jsonschema import ValidationError
from mock_module.api import MockRecord
from sqlalchemy.exc import IntegrityError

from invenio_communities.communities.records.api import Community


@pytest.fixture()
def c(app, db, location):
    """A community fixture."""
    _c = Community.create({})
    db.session.commit()
    return Community.get_record(_c.id)


@pytest.fixture()
def c2(app, db, location):
    """Another community fixture."""
    _c = Community.create({})
    db.session.commit()
    return Community.get_record(_c.id)


@pytest.fixture()
def record(app, db, c):
    """A community fixture."""
    r = MockRecord.create({})
    r.communities.add(c, default=True)
    r.commit()
    db.session.commit()
    return r


def test_record_create_empty(app, db):
    """Smoke test."""
    record = MockRecord.create({})
    db.session.commit()
    assert record.schema

    # JSONSchema validation works.
    pytest.raises(ValidationError, MockRecord.create, {"metadata": {"title": 1}})


def test_get(db, record, c):
    """Loading a record should load communties and default."""
    r = MockRecord.get_record(record.id)
    assert c in r.communities
    assert r.communities.default == c


def test_add(db, c):
    """Test adding a record to a community."""
    # With default
    record = MockRecord.create({})
    record.communities.add(c, default=True)
    assert record.communities.default == c
    record.commit()
    assert record["communities"] == {
        "default": str(c.id),
        "ids": [str(c.id)],
    }
    db.session.commit()

    # No default
    record = MockRecord.create({})
    record.communities.add(c)
    assert record.communities.default is None
    record.commit()
    assert record["communities"] == {"ids": [str(c.id)]}
    db.session.commit()


def test_add_existing(db, c):
    """Test addding same community twice."""
    record = MockRecord.create({})
    record.communities.add(c)
    record.communities.add(c)
    # Adding a community already added, will raise integrity error.
    pytest.raises(IntegrityError, record.commit)
    # Rollback to avoid error in pytest-invenio "location" fixture.
    db.session.rollback()


def test_len_contains(record, c, c2):
    assert len(record.communities) == 1
    assert c in record.communities
    assert str(c.id) in record.communities
    assert c2 not in record.communities
    assert str(c2.id) not in record.communities


def test_remove(db, c, record):
    """Test removal of community."""
    record.communities.remove(c)
    assert len(record.communities) == 0
    record.commit()
    assert record["communities"] == {}
    db.session.commit()

    # Removing non-existing raises an error
    pytest.raises(ValueError, record.communities.remove, c2)


def test_iter(db, record, c):
    # With cache hit
    assert list(record.communities) == [c]
    # Without cache hit
    record = MockRecord.get_record(record.id)
    assert list(record.communities) == [c]


def test_ids(db, record, c):
    assert list(record.communities.ids) == [str(c.id)]


def test_change_default(db, record, c, c2):
    assert record.communities.default == c
    del record.communities.default
    assert record.communities.default is None

    with pytest.raises(AttributeError):
        # record not part of c2, so will fail
        record.communities.default = c2

    record.communities.add(c2)
    record.communities.default = c2
    assert record.communities.default == c2


def test_clear(db, record):
    assert len(record.communities) == 1
    record.communities.clear()
    assert len(record.communities) == 0
    record.commit()
    assert record["communities"] == {}


def test_refresh(db, record, c2):
    assert len(record.communities) == 1
    # Mess up internals
    record.communities._communities_ids = set()
    record.communities._default_id = str(c2.id)
    record.commit()
    db.session.commit()
    # Still messed up
    record = MockRecord.get_record(record.id)
    assert len(record.communities) == 0
    # Refresh to fix
    record.communities.refresh()
    assert len(record.communities) == 1



# -*- coding: utf-8 -*-
#
# Copyright (C) 2021 CERN.
#
# Invenio-Communities is free software; you can redistribute it and/or
# modify it under the terms of the MIT License; see LICENSE file for more
# details.

"""Pytest configuration.

See https://pytest-invenio.readthedocs.io/ for documentation on which test
fixtures are available.
"""

import pytest
from invenio_app.factory import create_api
from invenio_indexer.api import RecordIndexer
from mock_module.api import MockRecord


@pytest.fixture(scope="module")
def extra_entry_points():
    """Extra entry points to load the mock_module features."""
    return {
        "invenio_db.model": [
            "mock_module = mock_module.models",
        ],
        "invenio_jsonschemas.schemas": [
            "mock_module = mock_module.jsonschemas",
        ],
        "invenio_search.mappings": [
            "mocks = mock_module.mappings",
        ],
    }


@pytest.fixture(scope="module")
def create_app(instance_path, entry_points):
    """Application factory fixture."""
    return create_api


@pytest.fixture()
def indexer():
    """Indexer instance with correct Record class."""
    return RecordIndexer(
        record_cls=MockRecord, record_to_index=lambda r: (r.index._name, "_doc")
    )



# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2016-2021 CERN.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Routes for community-related pages provided by Invenio-Communities."""

from flask import current_app, g, render_template
from flask_babelex import lazy_gettext as _
from flask_login import login_required
from invenio_records_resources.services.errors import PermissionDeniedError
from invenio_vocabularies.proxies import current_service as vocabulary_service

from invenio_communities.proxies import current_communities

from ..communities.resources.ui_schema import TypesSchema
from .decorators import pass_community

VISIBILITY_FIELDS = [
    {
        "text": "Public",
        "value": "public",
        "icon": "group",
        "helpText": _(
            "Your community is publicly accessible" " and shows up in search results."
        ),
    },
    {
        "text": "Restricted",
        "value": "restricted",
        "icon": "lock",
        "helpText": _("Your community is restricted to users" " with access."),
    },
]


def _filter_roles(action, member_types, community_id, identity=None):
    """Compute current identity roles for action, member type and community."""
    identity = identity or g.identity
    service_config = current_communities.service.config
    roles = []
    for role in current_app.config["COMMUNITIES_ROLES"]:
        permission = service_config.permission_policy_cls(
            action,
            community_id=community_id,
            role=role["name"],
            member_types=member_types,
        )
        if permission.allows(identity):
            roles.append(role)
    return roles


def _get_roles_can_update(community_id):
    """Get the full list of roles that current identity can update."""
    return _filter_roles("members_update", {"user", "group"}, community_id)


def _get_roles_can_invite(community_id):
    """Get the full list of roles that current identity can invite."""
    return dict(
        user=_filter_roles("members_invite", {"user"}, community_id),
        group=_filter_roles("members_add", {"group"}, community_id),
    )


def communities_frontpage():
    """Communities index page."""
    return render_template(
        "invenio_communities/frontpage.html",
    )


def communities_search():
    """Communities search page."""
    return render_template(
        "invenio_communities/search.html",
    )


@login_required
def communities_new():
    """Communities creation page."""
    return render_template(
        "invenio_communities/new.html",
        form_config=dict(
            access=dict(visibility=VISIBILITY_FIELDS),
            SITE_UI_URL=current_app.config["SITE_UI_URL"],
        ),
    )


@pass_community(serialize=True)
def communities_settings(pid_value, community, community_ui):
    """Community settings/profile page."""
    permissions = community.has_permissions_to(
        ["update", "read", "search_requests", "search_invites"]
    )
    if not permissions["can_update"]:
        raise PermissionDeniedError()

    _types = vocabulary_service.read_all(
        g.identity,
        fields=["id", "title"],
        type="communitytypes",
        max_records=10,
    )
    types_json = {
        "types": [{"id": i["id"], "title": i["title"]} for i in list(_types.hits)]
    }
    types_serialized = TypesSchema().dump(types_json)
    try:
        current_communities.service.read_logo(g.identity, pid_value)
        logo = True
    except FileNotFoundError:
        logo = False

    return render_template(
        "invenio_communities/details/settings/profile.html",
        community=community_ui,
        has_logo=True if logo else False,
        types=types_serialized["types"],
        permissions=permissions,  # hide/show UI components
        active_menu_tab="settings",
    )


@pass_community(serialize=True)
def communities_requests(pid_value, community, community_ui):
    """Community requests page."""
    permissions = community.has_permissions_to(
        ["update", "read", "search_requests", "search_invites"]
    )
    if not permissions["can_search_requests"]:
        raise PermissionDeniedError()

    return render_template(
        "invenio_communities/details/requests/index.html",
        community=community_ui,
        permissions=permissions,
    )


@pass_community(serialize=True)
def communities_settings_privileges(pid_value, community, community_ui):
    """Community settings/privileges page."""
    permissions = community.has_permissions_to(
        ["update", "read", "search_requests", "search_invites"]
    )
    if not permissions["can_update"]:
        raise PermissionDeniedError()

    return render_template(
        "invenio_communities/details/settings/privileges.html",
        community=community_ui,
        form_config=dict(
            access=dict(visibility=VISIBILITY_FIELDS),
        ),
        permissions=permissions,
    )


@pass_community(serialize=True)
def members(pid_value, community, community_ui):
    """Community members page."""
    permissions = community.has_permissions_to(
        [
            "update",
            "members_search",
            "members_search_public",
            "members_manage",
            "read",
            "search_requests",
            "search_invites",
            "invite_owners",
        ]
    )
    if not permissions["can_read"]:
        raise PermissionDeniedError()

    return render_template(
        "invenio_communities/details/members/members.html",
        community=community_ui,
        permissions=permissions,
        roles_can_update=_get_roles_can_update(community.id),
    )


@pass_community(serialize=True)
def invitations(pid_value, community, community_ui):
    """Community invitations page."""
    permissions = community.has_permissions_to(
        [
            "update",
            "read",
            "search_requests",
            "search_invites",
            "invite_owners",
        ]
    )
    if not permissions["can_search_invites"]:
        raise PermissionDeniedError()
    return render_template(
        "invenio_communities/details/members/invitations.html",
        community=community_ui,
        roles_can_invite=_get_roles_can_invite(community.id),
        permissions=permissions,
    )



# -*- coding: utf-8 -*-
#
# This file is part of Invenio.
# Copyright (C) 2016-2021 CERN.
#
# Invenio is free software; you can redistribute it and/or modify it
# under the terms of the MIT License; see LICENSE file for more details.

"""Invenio Communities Resource API config."""
import marshmallow as ma
from flask_resources import (
    HTTPJSONException,
    JSONSerializer,
    ResponseHandler,
    create_error_handler,
)
from invenio_records_resources.resources import RecordResourceConfig
from invenio_requests.resources.requests.config import RequestSearchRequestArgsSchema

from invenio_communities.communities.resources.serializer import (
    UICommunityJSONSerializer,
)
from invenio_communities.errors import CommunityFeaturedEntryDoesNotExistError

community_error_handlers = RecordResourceConfig.error_handlers.copy()
community_error_handlers.update(
    {
        FileNotFoundError: create_error_handler(
            HTTPJSONException(
                code=404,
                description="No logo exists for this community.",
            )
        ),
        CommunityFeaturedEntryDoesNotExistError: create_error_handler(
            lambda e: HTTPJSONException(
                code=404,
                description=str(e),
            )
        ),
    }
)


class CommunityResourceConfig(RecordResourceConfig):
    """Communities resource configuration."""

    blueprint_name = "communities"
    url_prefix = ""

    routes = {
        "communities-prefix": "/communities",
        "user-prefix": "/user/communities",
        "list": "",
        "item": "/<pid_value>",
        "featured-prefix": "/featured",
        "featured-id": "/<featured_id>",
        "community-requests": "/requests",
    }

    request_view_args = {
        **RecordResourceConfig.request_view_args,
        "featured_id": ma.fields.Int(),
    }
    error_handlers = community_error_handlers
    request_community_requests_search_args = RequestSearchRequestArgsSchema

    response_handlers = {
        "application/json": ResponseHandler(JSONSerializer()),
        "application/vnd.inveniordm.v1+json": ResponseHandler(
            UICommunityJSONSerializer()
        ),
    }



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 Northwestern University.
#
# Invenio-Communities is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Community base error."""

from flask_babelex import gettext as _


class CommunityError(Exception):
    """Base exception for community errors."""


class CommunityFeaturedEntryDoesNotExistError(CommunityError):
    """The provided set spec does not exist."""

    def __init__(self, query_arguments):
        """Initialise error."""
        super().__init__(
            _(
                "A featured community entry with {q} does not exist.".format(
                    q=query_arguments
                )
            )
        )



# -*- coding: utf-8 -*-
#
# Copyright (C) 2022 CERN.
#
# Invenio-App-RDM is free software; you can redistribute it and/or modify
# it under the terms of the MIT License; see LICENSE file for more details.

"""Configuration helper for React-SearchKit."""

from functools import partial

from flask import current_app
from invenio_search_ui.searchconfig import search_app_config


def search_app_context():
    """Search app context processor."""
    return {
        "search_app_communities_config": partial(
            search_app_config,
            config_name="COMMUNITIES_SEARCH",
            available_facets=current_app.config["COMMUNITIES_FACETS"],
            sort_options=current_app.config["COMMUNITIES_SORT_OPTIONS"],
            headers={"Accept": "application/json"},
            endpoint="/api/communities",
        ),
        "search_app_communities_requests_config": partial(
            search_app_config,
            config_name="COMMUNITIES_REQUESTS_SEARCH",
            available_facets=current_app.config["REQUESTS_FACETS"],
            sort_options=current_app.config["COMMUNITIES_SORT_OPTIONS"],
            headers={"Accept": "application/json"},
            initial_filters=[["is_open", "true"]],
            endpoint="/api/requests",
        ),
        "search_app_communities_members_config": partial(
            search_app_config,
            config_name="COMMUNITIES_MEMBERS_SEARCH",
            available_facets=current_app.config["COMMUNITIES_MEMBERS_FACETS"],
            sort_options=current_app.config["COMMUNITIES_MEMBERS_SORT_OPTIONS"],
            headers={"Accept": "application/json"},
            default_size=25,
            pagination_options=(25, 50, 75),
        ),
        "search_app_communities_invitations_config": partial(
            search_app_config,
            config_name="COMMUNITIES_INVITATIONS_SEARCH",
            available_facets=current_app.config["REQUESTS_FACETS"],
            sort_options=current_app.config["COMMUNITIES_INVITATIONS_SORT_OPTIONS"],
            headers={"Accept": "application/json"},
            initial_filters=[["is_open", "true"]],
            endpoint="/api/requests",
        ),
    }
